@@ -32,7 +32,7 @@
 
 struct pipe_loader_ops {
    struct pipe_screen *(*create_screen)(struct pipe_loader_device *dev,
-                                        const struct pipe_screen_config *config);
+                                        const struct pipe_screen_config *config, bool sw_vk);
 
    const struct driOptionDescription *(*get_driconf)(struct pipe_loader_device *dev,
                                                      unsigned *count);
