@@ -78,18 +78,22 @@ lp_setup_set_triangle_state( struct lp_setup_context *setup,
                              boolean front_is_ccw,
                              boolean scissor,
                              boolean half_pixel_center,
-                             boolean bottom_edge_rule);
+                             boolean bottom_edge_rule,
+                             boolean multisample);
 
 void 
 lp_setup_set_line_state( struct lp_setup_context *setup,
-                         float line_width);
+                         float line_width,
+                         boolean line_rectangular);
 
 void 
 lp_setup_set_point_state( struct lp_setup_context *setup,
-                          float point_size,                          
+                          float point_size,
+                          boolean point_tri_clip,
                           boolean point_size_per_vertex,
                           uint sprite_coord_enable,
-                          uint sprite_coord_origin);
+                          uint sprite_coord_origin,
+                          boolean point_quad_rasterization);
 
 void
 lp_setup_set_setup_variant( struct lp_setup_context *setup,
@@ -149,6 +153,10 @@ unsigned
 lp_setup_is_resource_referenced( const struct lp_setup_context *setup,
                                 const struct pipe_resource *texture );
 
+void
+lp_setup_set_sample_mask(struct lp_setup_context *setup,
+                         uint32_t sample_mask);
+
 void
 lp_setup_set_flatshade_first( struct lp_setup_context *setup, 
                               boolean flatshade_first );
@@ -161,6 +169,10 @@ void
 lp_setup_set_vertex_info( struct lp_setup_context *setup, 
                           struct vertex_info *info );
 
+void
+lp_setup_set_linear_mode( struct lp_setup_context *setup, 
+                          boolean permit_linear_rasterizer );
+
 void
 lp_setup_begin_query(struct lp_setup_context *setup,
                      struct llvmpipe_query *pq);
